@@ -7,6 +7,7 @@ from typing import (
     Optional
     )
 from datetime import datetime, timedelta, timezone
+from typing_extensions import Self
 from pydantic import(
     BaseModel,
     AnyHttpUrl,
@@ -44,20 +45,20 @@ class StatementReq(BaseModel):
     def check_timeframe(cls, values):
         """Fixes the timeframe if wrong."""
 
-        if values['to_'] is None:
+        if values.get('to_') is None:
             tfr = default_timeframe()
             values['from_'] = tfr[0]
             values['to_'] = tfr[1]
         else:
-            if values['from_'] is None:
+            if values.get('from_') is None:
                 tfr = default_timeframe(end_date=values['to_'])
                 values['from_'] = tfr[0]
                 values['to_'] = tfr[1]
             else:
                 delta = values['to_'] - values['from_']
-                valid_timeframe = int(delta.total_seconds()) > 0 and not int(delta.total_seconds()) > 2682000
+                valid_timeframe = int(delta.total_seconds()) > 0 and not int(delta.total_seconds()) > TIMEBLOCK.total_seconds()
                 if not valid_timeframe:
-                    values['from_'] = values['to_'] - timedelta(seconds=2682000)
+                    values['from_'] = values['to_'] - TIMEBLOCK
 
         return values
     
@@ -113,7 +114,22 @@ class Transaction(BaseModel):
             "amount": self.amount,
         }
 
-class StatementResp(BaseModel):
+    def __add__(self, other: Union[Self, 'Statement']) -> 'Statement':
+        if isinstance(other, type(self)):
+            both = [self, other]
+            both.sort(key=lambda x: x.time)
+            return Statement(transactions=both)
+        else:
+            try:
+                # In case adding a Statement
+                return other + self
+            except TypeError:
+                raise TypeError("Can only add Transaction or Statement to Transaction")
+
+    def __hash__(self):
+        return hash(self.id)
+
+class Statement(BaseModel):
     class Config:
         json_encoders=enum_encoders
 
@@ -133,12 +149,19 @@ class StatementResp(BaseModel):
             values['timeframe'] = (start, end)
         return values
 
-    def __add__(self, other: Any) -> 'StatementResp':
+    def __len__(self) -> int:
+        return len(self.transactions)
+        
+    def __add__(self, other: Union[Self, 'Transaction']) -> Self:
         """Add two statements."""
-
-        tx = self.transactions + other.transactions
+        if isinstance(other, type(self)):
+            tx = list(self.transactions) + list(other.transactions)
+        elif isinstance(other, Transaction):
+            tx = list(self.transactions) + [other,]
+        else:
+            raise TypeError("Can only add Transaction or Statement to Statement")
         tx.sort(key=lambda x: x.time)
-        return StatementResp(transactions=tx)
+        return Statement(transactions=tx)
 
     def __iter__(self) -> Iterator[Transaction]:
         """Returns an iterator over the transactions."""
@@ -150,6 +173,9 @@ class StatementResp(BaseModel):
 
         return self.transactions[index]
 
+    def __hash__(self):
+        return hash(tuple(self.transactions))
+
     def to_dict(self) -> dict:
         """Returns a dictionary with Transaction ids as keys and Transaction objects as values."""
 
@@ -241,7 +267,7 @@ class Account(BaseModel):
         engine_instance,
         fr: datetime,
         to: datetime,
-        ) -> StatementResp:
+        ) -> Statement:
         """Get the statement between dates using cached values where possible.
         Tz-info must be UTC.
         """
@@ -272,8 +298,8 @@ class Account(BaseModel):
                     self.cached_statement[date.isoformat()] = bucket
                     relevant_buckets.insert(0, bucket)
                 # BadRequest is returned by the API when requesting a timeframe that is too old.
-                except BadRequest:
-                    pass
+                except BadRequest: # pragma: no cover
+                    break # pragma: no cover
 
         whole_statement = list()
         for bucket in relevant_buckets:
@@ -281,9 +307,9 @@ class Account(BaseModel):
         whole_statement = [tx for tx in whole_statement if tx.time >= fr and tx.time <= to]
         whole_statement.sort(key=lambda x: x.time)
 
-        return StatementResp(transactions=whole_statement, timeframe=(fr, to))
+        return Statement(transactions=whole_statement, timeframe=(fr, to))
 
-class UserInfoResp(BaseModel):
+class User(BaseModel):
     class Config:
         extra='ignore'
         json_encoders=enum_encoders
@@ -296,7 +322,7 @@ class UserInfoResp(BaseModel):
     permissions: Optional[str] = None
 
 
-class CurrencyInfo(BaseModel):
+class CurrencyExchange(BaseModel):
     class Config:
         json_encoders=enum_encoders
 
@@ -308,8 +334,8 @@ class CurrencyInfo(BaseModel):
     rateCross: Optional[float] = None
 
 
-class CurrInfoResp(BaseModel):
+class Currencies(BaseModel):
     class Config:
         json_encoders=enum_encoders
 
-    rates: Sequence[CurrencyInfo]
+    rates: Sequence[CurrencyExchange]
