@@ -2,11 +2,14 @@ from .API import Client as Client
 from .API import MonoCaller as MonoCaller
 from .API import Account as Account
 from .API import Transaction as Transaction
-from .API import UserInfoResp as UserInfoResp
-from .API import StatementResp as StatementResp
-from .API import CurrencyInfo as CurrencyInfo
+from .API import User as User
+from .API import Statement as Statement
+from .API import CurrencyExchange as CurrencyExchange
 from .API import HeadersPrivate as HeadersPrivate
 from .API import StatementReq as StatementReq
 from .API import UserInfoReq as UserInfoReq
 from .API import CurrRateReq as CurrRateReq
 from .API import construct_bucket_list as construct_bucket_list
+from .API import default_timeframe as default_timeframe
+from .API.exceptions import TimeConstraintError as TimeConstraintError
+from .API import TIMEBLOCK
\ No newline at end of file
